package jp.clockmaker.utils {
	/**
	 * BetweenUtil
	 * @author Yasu
	 */
	public class BetweenUtil{
		import org.libspark.betweenas3.BetweenAS3;
		import org.libspark.betweenas3.core.easing.IEasing;
		import org.libspark.betweenas3.tweens.ITween;
		
		/**
		 * making custom easing method.
		 * カスタムイージングを作るメソッドです。
		 * @param    obj                動かしたい対象
		 * @param    to                 開始点
		 * @param    from               終了点
		 * @param    time               トゥイーンの時間(秒)
		 * @param    startEasing        開始時のイージング
		 * @param    endEasing          終了時のイージング
		 * @param    middlePercent      イージング切り替えの中間点をどこに指定するかの割合(0～1を指定)。ディフォルトは0.5。
		 * @return   ITween             合成されたトゥイーンインスタンス
		 */
		static public function customEase(obj:Object, to:Object, from:Object, time:Number, startEasing:IEasing, endEasing:IEasing, middlePercent:Number = 0.5): ITween {
			var middlePoint:Object = { };
			for (var param:String in to) {
				middlePoint[param] = to[param] * middlePercent + from[param] * (1 - middlePercent);
			}
			
			var tw1:ITween = BetweenAS3.tween(obj, middlePoint, from, time, startEasing);
			var tw2:ITween = BetweenAS3.tween(obj, to, middlePoint, time, endEasing);
			
			var tw3:ITween = BetweenAS3.serial(tw1, tw2);
			var tw4:ITween = BetweenAS3.scale(tw3, time / tw3.duration);
			
			return tw4;
		}
	}
}